#
# spec file for package rocksndiamonds (Version 3.2.4)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           rocksndiamonds
BuildRequires:  SDL_image-devel SDL_mixer-devel SDL_net-devel fdupes update-desktop-files
License:        GPLv2+
Group:          Amusements/Games/Action/Arcade
Provides:       rockdiam
Obsoletes:      rockdiam
AutoReqProv:    on
Version:        3.2.4
Release:        94.2
PreReq:         permissions
Summary:        Arcade style game with stereo sounds
Url:            http://www.artsoft.org/rocksndiamonds/
Source:         %{name}-%{version}.tar.bz2
Source2:        %{name}.png
Source3:        %{name}.desktop
Source4:        Contributions-1.2.0.tar.bz2
Patch:          %{name}-%{version}-smpeg.patch
Patch1:         %{name}-%{version}-gcc4.patch
Patch2:         %{name}-CVE-2011-4606.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A game like "Boulderdash" (C 64) or "Emerald Mine" (Amiga). Included
are many levels known from the games "Boulderdash", "Emerald Mine",
"Sokoban", "Supaplex" and "DX-Boulderdash", level elements for "Diamond
Caves II" style games and a lot of new levels designed by other
players.

Some features:

- joystick support for Linux, FreeBSD and DOS/Windows

- local multiplayer support for all supported platforms

- network multiplayer support for Unix platform

- soft scrolling with 50 frames/s

- stereo sound effects and music

- music module support for SDL version (Unix/Win32)

- fullscreen support for SDL version (Unix/Win32)

- lots of additional levels available (over 10.000)



Authors:
--------
    Holger Schemel <info@artsoft.org>

%prep
%setup -q
if [ ! -f /usr/%_lib/libsmpeg.a ] ; then
%patch
fi
%patch1
%patch2 -p1
cp %{S:2} %{S:3} .
pushd levels
tar xjf %{S:4}
popd

%build
make sdl \
    OPTIONS="$RPM_OPT_FLAGS" \
    XLIB_PATH=/usr/X11R6/%{_lib} \
    RO_GAME_DIR=/usr/share/games/rocksndiamonds \
    RW_GAME_DIR=/var/games/rocksndiamonds

%install
rm -rf $RPM_BUILD_ROOT
LIBDIR=$RPM_BUILD_ROOT/usr/share/games/rocksndiamonds
SCOREDIR=$RPM_BUILD_ROOT/var/games/rocksndiamonds
install -m 755 -d $LIBDIR
install -m 755 -d $SCOREDIR
install -m 755 -d $RPM_BUILD_ROOT/usr/games
install -m 755 -d $RPM_BUILD_ROOT%{_mandir}/man6
install -m 755 -d $RPM_BUILD_ROOT/usr/share/pixmaps
cp -a graphics $LIBDIR
cp -a sounds $LIBDIR
cp -a music $LIBDIR
cp -a levels $LIBDIR
find $LIBDIR/levels -name '*.orig' | xargs rm
find $LIBDIR -type f -exec chmod 644 \{\} \;
find $LIBDIR -type d -exec chmod 755 \{\} \;
install -m 755 rocksndiamonds $RPM_BUILD_ROOT/usr/games
install -m 644 rocksndiamonds.1 $RPM_BUILD_ROOT%{_mandir}/man6/rocksndiamonds.6
install -m 644 rocksndiamonds.png $RPM_BUILD_ROOT/usr/share/pixmaps
%suse_update_desktop_file -i rocksndiamonds Game ArcadeGame
%fdupes $RPM_BUILD_ROOT

%post
%run_permissions
%verifyscript
%verify_permissions -e /usr/games/rocksndiamonds

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc CHANGES COPYING CREDITS HARDWARE README TODO rocksndiamonds-*.lsm 
%doc %{_mandir}/man6/*
%verify(not mode) %attr(0755,games,games) /usr/games/rocksndiamonds
/usr/share/games/rocksndiamonds
/usr/share/applications/rocksndiamonds.desktop
/usr/share/pixmaps/rocksndiamonds.png
%attr(775,games,games) /var/games/rocksndiamonds

%changelog
* Fri Jul 13 2012 meissner@suse.com
- do not create ~/.rocksndiamonds/ world writeable.
  bnc#736261 / CVE-2011-4606
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Oct 31 2008 meissner@suse.de
- run fdupes
* Wed Mar  5 2008 anosek@suse.cz
- updated to version 3.2.4
  * lots of improvements and bugfixes. See ChangeLog for the full list
  * title messages are now also searched in graphics artwork directory;
  those found in graphics directory have precendence over those found
  in level directory -- this handles title messages stored in graphics
  directories as part of the artwork set, just like title images; this
  makes sense, as corresponding special font definitions for messages
  are usually defined in the same graphics artwork directory, and also
  because title images and title messages that are combined in a level
  set introduction should usually not be separated when the level set
  is used with a different artwork set (e.g. using "override graphics")
  * added use of hashes created from static lists (element tokens, image
  config, font tokens) to speed up lookup of configuration parameters
  * added "busy" animation when initializing program and loading artwork
  * added initialization profiling for program startup (debugging only)
  * added graphics engine directive "border.draw_masked_when_fading" that
  enables/disables drawing of border mask over screen that is just faded
  * added additional configuration directives for setup screen draw offset
  menu.draw_xoffset.SETUP[XXX] and menu.draw_yoffset.SETUP[XXX] with XXX
  in GAME, EDITOR, GRAPHICS, SOUND, ARTWORK, INPUT, SHORTCUTS_1,
  SHORTCUTS_2, CHOOSE_ARTWORK, CHOOSE_OTHER (where "CHOOSE_ARTWORK" is
  used to define draw offset on custom artwork selection screens and
  "CHOOSE_OTHER" is used on all other list style selection screens, like
  choosing game speed or screen mode for fullscreen mode)
  * added eight pure decoration graphic definitions for the game panel
  * added support for accessing native Diamond Caves II level packages
  * added game panel control to display arbitrary elements on game panel
  * added game panel control to display custom element score (globally
  unique for identical custom elements) either as value or as element
  * added ".draw_masked" and ".draw_order" to game panel control drawing
  * added displaying of gravity state (on/off) as new game panel control
  * added animation for game panel elements (similar to game elements)
  * added new pseudo game mode "PANEL" to define panel fonts and graphics
  - panel fonts now use ".PANEL" suffix instead of ".PLAYING" suffix
  - panel graphics now use ".PANEL" suffix instead of ".DOOR" suffix
  (else graphics would have to use ".PLAYING", which would be confusing)
  * added attribute ".tile_size" for element style game panel controls
  * added <space> key as additional valid key to use for confirm requester
  * improved menu fading, adding separate fading definitions for entering
  and leaving a "content" screen (in general), and optional definitions
  for the special "content" screens SCORES, EDITOR, INFO and PLAYING
  * added (currently invisible) setup option to define scroll delay value
  * added option "game.forced_scroll_delay_value" to override user choice
  of scroll delay value for certain level sets with "graphicsinfo.conf"
  * replaced setup option "scroll delay: on/off" by new setup option that
  directly allows selecting the desired scroll delay value from 0 to 8
  * added displaying of most game panel control elements (not animated)
  * added new configuration directives to display additional game engine
  values on the game control panel, like the following examples:
  - game.panel.time_hh/time_mm/time_ss	- level time in HH/MM/SS format
  - game.panel.penguins			- number of penguins to rescue
  - game.panel.level_name		- level name of current level
  * added support for preview tile sizes "1" and "2" (1x1 and 2x2 pixels)
  * added new player option "no centering when relocating" for "invisible"
  teleportations to level areas that look exactly the same, giving the
  illusion that the player did not relocate at all (this was the default
  since 3.2.3, but caused visual problems with room creation in "Zelda")
  * added new menu fading effect "melt", shamelessly stolen from "DOOM"
  * improved menu fading, adding separate fading definitions for entering
  and leaving a menu and for fading between menu and "content" screens
  * improved menu fading, adding separate fading definitions for fading
  between menu screens and fading between menu and "destination" screens
  * titlemessage_initial_x and titlemessage_x set to "[DEFAULT]" in static
  configuration (set from "[titlemessage_initial]" and "[titlemessage]")
  * fading settings of "[titlemessage_initial]" and "[titlemessage]" set
  to "[DEFAULT]" in static configuration (set from "[title_initial]" and
  "[title]")
  * improved title fading, allowing fading animation types "none", "fade"
  and "crossfade" (including cross-fading of last title to main menu)
  .......
* Sat May 19 2007 coolo@suse.de
- remove X-SuSE-translate from desktop file
* Mon Mar  5 2007 ssommer@suse.de
- BuildRequires SDL_net-devel
* Mon Feb  5 2007 anosek@suse.cz
- updated to version 3.2.3
  * bugfix release
  * some improvements on program startup performance
* Mon Sep 11 2006 anosek@suse.cz
- updated to version 3.2.2
  - instant tape reloading for the last saved tape using "quick save/load"
  - fixed bug that prevented solving levels without exit (like in Sokoban)
  - fixed bug with quick loading tapes in fullscreen with EMC game engine
  - fixed level time for EMC levels (needed for the upcoming EMC collection)
  - added key shortcut "Alt + Enter" to toggle fullscreen mode at any time
  - added support for mouse scroll wheel for all scrollbar gadgets
  - added support for horizontal mouse wheel scrolling by holding "Shift"
  - added support for single step mouse wheel scrolling by holding "Alt"
  - improved down-scaling of images for better editor and preview graphics
* Thu Aug  3 2006 anosek@suse.cz
- updated to version 3.2.0
  - finished new native game engine for Emerald Mine (Club) levels
  - added all new elements from EMC engine also to R'n'D engine
  - added selection between ECS and AGA graphics for EMC levels to setup
  - added multi-player support for EMC game engine (with up to four players)
  - added player switching (visual and quick) to R'n'D and EM game engine
  - added key shortcut settings for switching player focus to setup menu
  - added custom element actions for CE change page in level editor
  - added "CE value" and "CE score" counters for custom elements
  - added cascaded element lists to element list in level editor
  - added dynamic element list with all elements used in current level
  - added special Supaplex animations for Murphy being bored and sleeping
  - added setup option to display element token name in level editor
  - added up to five title screens for each level set to show after loading
  - added credits pages to the "credits" section that were really missing
  - lots of bugfixes and internal engine changes (see ChangeLog file)
- dropped obsolete patches
  rocksndiamonds-3.1.1-overflow.patch
  rocksndiamonds-3.1.1-userlevels.patch
* Wed Feb  1 2006 mmarek@suse.cz
- fix user levels being readonly after last update
  (userlevels.patch) (patch from upstream)
* Tue Jan 31 2006 mmarek@suse.cz
- fix buffer overflow reported by David Binderman
  [#146444] (overflow.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 mmarek@suse.cz
- added contributed levels
- added icon
* Mon Dec 19 2005 mmarek@suse.cz
- updated to 3.1.1
* Tue Apr 12 2005 mcihar@suse.cz
- fix for gcc 4
* Mon Jan 31 2005 ro@suse.de
- fix build
* Wed Aug  4 2004 mcihar@suse.cz
- update to 3.1.0
* Fri Mar 19 2004 mcihar@suse.cz
- remove *.orig files
* Wed Mar  3 2004 mcihar@suse.cz
- update to 3.0.8
* Wed Oct 29 2003 mcihar@suse.cz
- package according to permissions.secure and add %%run_permissions
- no root for build
* Tue Oct 14 2003 mcihar@suse.cz
- install in /usr/games and /usr/share/games
- update to 3.0.6 (mostly bugfixes)
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Thu Aug  7 2003 mcihar@suse.cz
- updated to 3.0.0:
  - graphics and sounds now completely and dynamically customizable
  - element animation length, speed and mode now freely configurable
  - 128 custom elements with lots of configurable element properties
  - advanced custom element settings for powerful, self-created elements
  - automatic tape playing function for game engine and level testing
  - added support for stereo WAV sound files
  - added support for background images for all menu screens
  - added some example levels showing how to create custom artwork
  - fixed Supaplex gravity tubes
  - fixed very nasty bug in SDL_image (and X11) PCX loading routine
  - fixed some very nasty bugs in bitmap zoom routine
  - fixed very nasty bug in level/artwork loading routine
- no more patches needed
- SDL version is being built now
* Thu Feb  6 2003 mcihar@suse.cz
- updated to 2.1.1:
  - sound bug (causing crashes) fixed (reported by Keith Peterston)
  - support for /dev/sound/dsp (devfs) added (thanks to Christoph Bauer)
  - added new contributed levels from the following players:
    + Alan Bond
    + Gerrit Holl
* Tue Aug  6 2002 mcihar@suse.cz
- updated to 2.1.0:
  - graphics, sounds and music now fully configurable
  - added support for TrueColor PCX graphics files
  - added support for 16 bit WAV sound files
  - enhanced sound system (especially regarding stereo and loop sounds)
  - new structured setup menu (with sub-menues for graphics and sounds)
  - added "quick save" and "quick load" functions with shortcut key
  - added single-step playing mode (automatic pause after each step)
  - behaviour of "Escape" key in level editor now more intuitive
  - changed default slipping behaviour of gems back to 2.0.0 style;
  this is now an element property for gems in the level editor,
  although existing converted levels use the new EM gems behaviour
  - bug fixed that prevented walking through tubes when gravity on
  - added Boulder Dash style "snap-pushing" (thanks to Achim Hrtel)
  - fixed memory leak in image loading code
  - fixed some "solid" elements that were accidentally destructible
  - fixed some tape stuff
  - added new contributed levels and graphics from players
* Sun Aug  4 2002 ro@suse.de
- group name changed "game" -> "games"
* Tue Jun 11 2002 mcihar@suse.cz
- updated to 2.0.1
  - bug in explosion code fixed that broke level 24 of "Baby Ghost Mine"
  - several Supaplex emulation bugs fixed (thanks to Mihail Milushev):
  - behaviour of robots adjusted to make them less aggressive
  - bug when selecting default level series fixed
  - new IFF style file format for level and tape files
  - bug in storing amoeba content fixed
  - nasty tape bugs fixed (completely reworked tape stuff)
  - file permissions when saving files and creating directories changed
  - some small sound bugs fixed
  - added new contributed levels
* Thu Jan 10 2002 cihlar@suse.cz
- use %%{_lib}
* Wed Sep 19 2001 ro@suse.de
- unified changelog
* Mon Mar 12 2001 cihlar@suse.cz
- fixed to compile on axp
* Thu Mar  8 2001 cihlar@suse.cz
- update to version 2.0.0
* Thu Feb  8 2001 cihlar@suse.cz
- fixed to compile
* Fri Dec  8 2000 cihlar@suse.cz
- added missing levels
* Fri Dec  1 2000 cihlar@suse.cz
- again fixed file permissions
* Wed Nov 15 2000 cihlar@suse.cz
- renamed rockdiam -> rocksndiamonds
- clean up spec file
- fixed file permissions
* Tue Apr 18 2000 cihlar@suse.cz
- upgrade to version 1.4.0
- added BuildRoot
* Sun Mar  5 2000 olh@suse.de
- move manpages
* Mon Jan 31 2000 uli@suse.de
- fixed misuse of va_arg macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Mar 12 1999 uli@suse.de
- update 0.9b -> 1.3.0
- eliminated Makefile.Linux
* Mon Oct 20 1997 hf@suse.de
- ready for autobuild
* Mon Jun  9 1997 hf@suse.de
- Changing the permissions for the highscorefiles.
* Fri Jun  6 1997 hf@suse.de
- Changing the permissions for the highscoredirectory.
* Mon May  5 1997 hf@suse.de
- The binary rocksndiamonds has the sgid game
  for edit the highscore and name files.
* Thu Mar  6 1997 hf@suse.de
- Version 0.9
  Anpassungen im Makefile, zustzliche defines angelegt
